> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #M-BUS RF click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on AVR
```
#include <stdint.h>
#include <stdbool.h>
#include <stddef.h>
#include "mbus_hw.h"

#define BUFFER_SIZE 300

sbit MBUS_RST     at PORTA6_bit;
sbit MBUS_RST_DIR at DDA6_bit;
sbit MBUS_RTS     at PORTA5_bit;
sbit MBUS_RTS_DIR at DDA5_bit;
sbit MBUS_CTS     at PORTD2_bit;
sbit MBUS_CTS_DIR at DDD2_bit;

bool response_finished;
bool ok_response;
bool my_receive_flag = false;

void system_setup( void )
{
    //GPIOs
    MBUS_CTS_DIR = 0;
    MBUS_RST_DIR = 0;
    MBUS_RTS_DIR = 1;

    //UART for terminal
    UART1_Init( 19200 );

    //MBus
    mbus_init();                                                /**< Initialize MBus HAL Layer */
    Delay_ms(1000);

    //UART
    UCSRB |= ( 1 << RXCIE );
    SREG  |= ( 1 << SREG_I );
}

void clear_transmit_buffer( transmit_frame_t *transmit_frame )
{
    uint8_t i = 0;

    for ( i = 0; i < 100; i++ )
        transmit_frame->data_field[i] = 0;
}

void mbus_uart_interupt() iv IVT_ADDR_USART__RXC ics ICS_AUTO
{
           char tmp = UART_Read();
           mbus_rx_isr( tmp );
}

```

```
void main()
{
    // Local Declarations
    uint8_t serial_num_buff[20] = { 0 };
    char long_text[100] = { 0 };
    uint16_t my_threshold = 0;
    uint8_t status = 0;
    uint8_t buffer[20] = { 0 };
    uint8_t new_meter[6] = { 0, 1, 2, 3, 4, 5 };
    uint8_t received_meter[8] = { 0 };
    date_time_t *my_time;
    transmit_frame_t *transmit_frame;
    status_t my_status = 0;


    // Malloc space for the Transmit Frame
    MM_Init();
    transmit_frame = Malloc( sizeof( transmit_frame_t ) );
    my_time = Malloc( sizeof( date_time_t ) );
    // Setup GPIOs, communication pins, interrupts, e.t.c.
    system_setup();


    //Initialize Conifguration Mode
    mbus_at_init();

    // Get firmware bootloader
    mbus_get_firmware_bootloader_vers( buffer );

    // Get single channel lbt delay
    my_status = mbus_get_single_channel_lbt_delay( &my_threshold );
    Delay_ms(200);
    LongToStr( my_threshold, buffer );

    // Set Date / Time
    my_time->month  = 7;
    my_time->day    = 21;
    my_time->hour   = 14;
    my_time->minute = 30;
    my_time->year   = 16;
    my_time->second = 27;

    // Get Date / Time
    Delay_ms(200);
    status = mbus_get_date_time( my_time );

    // Get Serial Number
    mbus_get_serial_number( serial_num_buff );

    // Get RX / TX Pins
    mbus_get_tx_rx_pins( buffer );

    // Set MBUS Mode
    mbus_set_mbus_mode( ROLE_N1_METER );

    // Set RX / TX formats
    mbus_set_serial_tx_format( LENGTH_TX );   // TX Format must have Length.. so that sending / receiving works properly

    // Add a meter
    mbus_set_meter_address( new_meter );        //Test setting a meter
    mbus_get_meter_address( received_meter );   //Test getting a meter
    status = mbus_add_edit_meter( DONT_FILTER, new_meter, 0, NO_ENCRYPT, NULL );


    //Try sending some data...
    // Set OP Mode
    mbus_op_init();
    //Send Frame
    sprintf( transmit_frame->data_field, "My Name is Corey Allen Lakey and I am %d Years Old.", 21 );
    transmit_frame->length_field = strlen( transmit_frame->data_field );
    mbus_send_frame( transmit_frame, 1 );              /**< Using length field for TX format, so not length needed */

    UART1_Write_Text( "Finished!\r\n" );
    while ( 1 );
}

```

